@@ -6,8 +6,8 @@
 # "License"); you may not use this file except in compliance
 # with the License.  You may obtain a copy of the License at
 #
-#     http://www.apache.org/licenses/LICENSE-2.0
 #
+#     http://www.apache.org/licenses/LICENSE-2.0
 #
 #
 # Unless required by applicable law or agreed to in writing,
@@ -18,16 +18,18 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
+from aliyunsdkcdn.endpoint import endpoint_data
+
 class DescribeLiveStreamRecordIndexFileRequest(RpcRequest):
 
 	def __init__(self):
 		RpcRequest.__init__(self, 'Cdn', '2014-11-11', 'DescribeLiveStreamRecordIndexFile')
+		self.set_method('POST')
+		if hasattr(self, "endpoint_map"):
+			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
+		if hasattr(self, "endpoint_regional"):
+			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-	def get_RecordId(self):
-		return self.get_query_params().get('RecordId')
-
-	def set_RecordId(self,RecordId):
-		self.add_query_param('RecordId',RecordId)
 
 	def get_AppName(self):
 		return self.get_query_params().get('AppName')
@@ -41,6 +43,12 @@ class DescribeLiveStreamRecordIndexFileRequest(RpcRequest):
 	def set_SecurityToken(self,SecurityToken):
 		self.add_query_param('SecurityToken',SecurityToken)
 
+	def get_StreamName(self):
+		return self.get_query_params().get('StreamName')
+
+	def set_StreamName(self,StreamName):
+		self.add_query_param('StreamName',StreamName)
+
 	def get_DomainName(self):
 		return self.get_query_params().get('DomainName')
 
@@ -53,8 +61,8 @@ class DescribeLiveStreamRecordIndexFileRequest(RpcRequest):
 	def set_OwnerId(self,OwnerId):
 		self.add_query_param('OwnerId',OwnerId)
 
-	def get_StreamName(self):
-		return self.get_query_params().get('StreamName')
+	def get_RecordId(self):
+		return self.get_query_params().get('RecordId')
 
-	def set_StreamName(self,StreamName):
-		self.add_query_param('StreamName',StreamName)
\ No newline at end of file
+	def set_RecordId(self,RecordId):
+		self.add_query_param('RecordId',RecordId)
\ No newline at end of file
