@@ -6,8 +6,8 @@
 # "License"); you may not use this file except in compliance
 # with the License.  You may obtain a copy of the License at
 #
-#     http://www.apache.org/licenses/LICENSE-2.0
 #
+#     http://www.apache.org/licenses/LICENSE-2.0
 #
 #
 # Unless required by applicable law or agreed to in writing,
@@ -18,16 +18,18 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
+from aliyunsdkcdn.endpoint import endpoint_data
+
 class SetForwardSchemeConfigRequest(RpcRequest):
 
 	def __init__(self):
 		RpcRequest.__init__(self, 'Cdn', '2014-11-11', 'SetForwardSchemeConfig')
+		self.set_method('POST')
+		if hasattr(self, "endpoint_map"):
+			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
+		if hasattr(self, "endpoint_regional"):
+			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-	def get_SchemeOrigin(self):
-		return self.get_query_params().get('SchemeOrigin')
-
-	def set_SchemeOrigin(self,SchemeOrigin):
-		self.add_query_param('SchemeOrigin',SchemeOrigin)
 
 	def get_SchemeOriginPort(self):
 		return self.get_query_params().get('SchemeOriginPort')
@@ -47,6 +49,12 @@ class SetForwardSchemeConfigRequest(RpcRequest):
 	def set_Enable(self,Enable):
 		self.add_query_param('Enable',Enable)
 
+	def get_SchemeOrigin(self):
+		return self.get_query_params().get('SchemeOrigin')
+
+	def set_SchemeOrigin(self,SchemeOrigin):
+		self.add_query_param('SchemeOrigin',SchemeOrigin)
+
 	def get_DomainName(self):
 		return self.get_query_params().get('DomainName')
 
