@@ -6,8 +6,8 @@
 # "License"); you may not use this file except in compliance
 # with the License.  You may obtain a copy of the License at
 #
-#     http://www.apache.org/licenses/LICENSE-2.0
 #
+#     http://www.apache.org/licenses/LICENSE-2.0
 #
 #
 # Unless required by applicable law or agreed to in writing,
@@ -18,22 +18,18 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
+from aliyunsdkcdn.endpoint import endpoint_data
+
 class SetIgnoreQueryStringConfigRequest(RpcRequest):
 
 	def __init__(self):
 		RpcRequest.__init__(self, 'Cdn', '2014-11-11', 'SetIgnoreQueryStringConfig')
+		self.set_method('POST')
+		if hasattr(self, "endpoint_map"):
+			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
+		if hasattr(self, "endpoint_regional"):
+			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-	def get_KeepOssArgs(self):
-		return self.get_query_params().get('KeepOssArgs')
-
-	def set_KeepOssArgs(self,KeepOssArgs):
-		self.add_query_param('KeepOssArgs',KeepOssArgs)
-
-	def get_HashKeyArgs(self):
-		return self.get_query_params().get('HashKeyArgs')
-
-	def set_HashKeyArgs(self,HashKeyArgs):
-		self.add_query_param('HashKeyArgs',HashKeyArgs)
 
 	def get_SecurityToken(self):
 		return self.get_query_params().get('SecurityToken')
@@ -47,6 +43,12 @@ class SetIgnoreQueryStringConfigRequest(RpcRequest):
 	def set_Enable(self,Enable):
 		self.add_query_param('Enable',Enable)
 
+	def get_KeepOssArgs(self):
+		return self.get_query_params().get('KeepOssArgs')
+
+	def set_KeepOssArgs(self,KeepOssArgs):
+		self.add_query_param('KeepOssArgs',KeepOssArgs)
+
 	def get_DomainName(self):
 		return self.get_query_params().get('DomainName')
 
@@ -57,4 +59,10 @@ class SetIgnoreQueryStringConfigRequest(RpcRequest):
 		return self.get_query_params().get('OwnerId')
 
 	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
\ No newline at end of file
+		self.add_query_param('OwnerId',OwnerId)
+
+	def get_HashKeyArgs(self):
+		return self.get_query_params().get('HashKeyArgs')
+
+	def set_HashKeyArgs(self,HashKeyArgs):
+		self.add_query_param('HashKeyArgs',HashKeyArgs)
\ No newline at end of file
