@@ -6,8 +6,8 @@
 # "License"); you may not use this file except in compliance
 # with the License.  You may obtain a copy of the License at
 #
-#     http://www.apache.org/licenses/LICENSE-2.0
 #
+#     http://www.apache.org/licenses/LICENSE-2.0
 #
 #
 # Unless required by applicable law or agreed to in writing,
@@ -18,10 +18,18 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
+from aliyunsdkcdn.endpoint import endpoint_data
+
 class SetReqAuthConfigRequest(RpcRequest):
 
 	def __init__(self):
 		RpcRequest.__init__(self, 'Cdn', '2014-11-11', 'SetReqAuthConfig')
+		self.set_method('POST')
+		if hasattr(self, "endpoint_map"):
+			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
+		if hasattr(self, "endpoint_regional"):
+			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
+
 
 	def get_Key1(self):
 		return self.get_query_params().get('Key1')
@@ -35,6 +43,18 @@ class SetReqAuthConfigRequest(RpcRequest):
 	def set_Key2(self,Key2):
 		self.add_query_param('Key2',Key2)
 
+	def get_TimeOut(self):
+		return self.get_query_params().get('TimeOut')
+
+	def set_TimeOut(self,TimeOut):
+		self.add_query_param('TimeOut',TimeOut)
+
+	def get_AuthType(self):
+		return self.get_query_params().get('AuthType')
+
+	def set_AuthType(self,AuthType):
+		self.add_query_param('AuthType',AuthType)
+
 	def get_AuthRemoteDesc(self):
 		return self.get_query_params().get('AuthRemoteDesc')
 
@@ -57,16 +77,4 @@ class SetReqAuthConfigRequest(RpcRequest):
 		return self.get_query_params().get('OwnerId')
 
 	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_TimeOut(self):
-		return self.get_query_params().get('TimeOut')
-
-	def set_TimeOut(self,TimeOut):
-		self.add_query_param('TimeOut',TimeOut)
-
-	def get_AuthType(self):
-		return self.get_query_params().get('AuthType')
-
-	def set_AuthType(self,AuthType):
-		self.add_query_param('AuthType',AuthType)
\ No newline at end of file
+		self.add_query_param('OwnerId',OwnerId)
\ No newline at end of file
