@@ -37,6 +37,12 @@ class DescribeDomainMax95BpsDataRequest(RpcRequest):
 	def set_StartTime(self,StartTime):
 		self.add_query_param('StartTime',StartTime)
 
+	def get_Cycle(self):
+		return self.get_query_params().get('Cycle')
+
+	def set_Cycle(self,Cycle):
+		self.add_query_param('Cycle',Cycle)
+
 	def get_DomainName(self):
 		return self.get_query_params().get('DomainName')
 
@@ -53,4 +59,10 @@ class DescribeDomainMax95BpsDataRequest(RpcRequest):
 		return self.get_query_params().get('OwnerId')
 
 	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
\ No newline at end of file
+		self.add_query_param('OwnerId',OwnerId)
+
+	def get_TimePoint(self):
+		return self.get_query_params().get('TimePoint')
+
+	def set_TimePoint(self,TimePoint):
+		self.add_query_param('TimePoint',TimePoint)
\ No newline at end of file
