@@ -83,10 +83,4 @@ class SetDomainServerCertificateRequest(RpcRequest):
 		return self.get_query_params().get('OwnerId')
 
 	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_Region(self):
-		return self.get_query_params().get('Region')
-
-	def set_Region(self,Region):
-		self.add_query_param('Region',Region)
\ No newline at end of file
+		self.add_query_param('OwnerId',OwnerId)
\ No newline at end of file
